@@ -1,33 +1,36 @@
-(* Copyright (C) 2000-2003, Luca Padovani <luca.padovani@cs.unibo.it>,
- *                          Claudio Sacerdoti Coen <sacerdot@cs.unibo.it>.
+(* Copyright (C) 2000-2005,
+ *    Luca Padovani	      <lpadovan@cs.unibo.it>
+ *    Claudio Sacerdoti Coen  <sacerdot@cs.unibo.it>
+ *    Stefano Zacchiroli      <zacchiro@cs.unibo.it>
  *
- * This file is part of lablgtkmathview, the Ocaml binding
- * for the GtkMathView widget.
+ * This file is part of lablgtkmathview, the Ocaml binding for the
+ * GtkMathView widget.
  * 
  * lablgtkmathview is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
+ * modify it under the terms of the GNU General Public License as
+ * published by the Free Software Foundation; either version 2 of the
+ * License, or (at your option) any later version.
  *
  * lablgtkmathview is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
  * along with lablgtkmathview; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
+ * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA
+ * 02111-1307, USA.
  * 
- * For details, send a mail to the author.
+ * For details, send a mail to the authors.
  *)
 
 class single_selection_math_view_signals :
   ([> `gtk | `mathview_gmetadom | `widget] as 'b) Gtk.obj ->
   ((Gdome.element option -> unit) -> unit) ->
- object
-  inherit GMathView.math_view_signals
-  method selection_changed : (Gdome.element_of_node option -> unit) -> unit
- end
+  object
+    inherit GMathView.math_view_signals
+    method selection_changed : (Gdome.element_of_node option -> unit) -> unit
+  end
 
 class single_selection_math_view :
   Gtk_mathview.math_view Gtk.obj ->
@@ -48,9 +51,8 @@ val single_selection_math_view :
   ?height:int ->
   ?packing:(GObj.widget -> unit) ->
   ?show:bool ->
-  unit -> single_selection_math_view
-
-  (** EXPERIMENTAL STUFF from now on: use with care and at your own risk! *)
+  unit ->
+    single_selection_math_view
 
 class multi_selection_math_view :
   Gtk_mathview.math_view Gtk.obj ->
@@ -71,6 +73,6 @@ val multi_selection_math_view :
   ?height:int ->
   ?packing:(GObj.widget -> unit) ->
   ?show:bool ->
-  unit -> multi_selection_math_view
-
+  unit ->
+    multi_selection_math_view
 
